@@ -90,6 +90,12 @@ class OsvService(VulnerabilityService):
 
             id = vuln["id"]
 
+            # If the vulnerability has been withdrawn, we skip it entirely.
+            withdrawn_at = vuln.get("withdrawn")
+            if withdrawn_at is not None:
+                logger.debug(f"OSV vuln entry '{id}' marked as withdrawn at {withdrawn_at}")
+                continue
+
             # The summary is intended to be shorter, so we prefer it over
             # details, if present. However, neither is required.
             description = vuln.get("summary")
